Structs
Enums
- Task
Priority - High priority tasks are scheduled preferentially over low priority tasks.
Constants
Functions
- block_
in_ place - Runs the given function on this thread while allowing another thread to take over this thread’s task execution duties.
- is_
scheduling_ polars_ executor_ thread - Returns whether this thread is actively used for scheduling tasks.
- spawn
- task_
scope - track_
task_ metrics