Module executor

Module executor 

Structs

AbortOnDropHandle
CancelHandle
JoinHandle
TaskMetrics
TaskScope

Enums

TaskPriority
High priority tasks are scheduled preferentially over low priority tasks.

Constants

ALLOW_RAYON_THREADS
THREAD_SPAWNED_BY_POLARS_EXECUTOR

Functions

block_in_place
Runs the given function on this thread while allowing another thread to take over this thread’s task execution duties.
is_scheduling_polars_executor_thread
Returns whether this thread is actively used for scheduling tasks.
spawn
task_scope
track_task_metrics