pub struct Linearizer<T> { /* private fields */ }Expand description
Utility to convert the input of N senders of ordered data into 1 stream of ordered data.
Implementations
Sourceimpl<T: Ord> Linearizer<T>
impl<T: Ord> Linearizer<T>
pub fn new(num_inserters: usize, buffer_size: usize) -> (Self, Vec<Inserter<T>>)
pub fn new_with_maintain_order( num_inserters: usize, buffer_size: usize, maintain_order: bool, ) -> (Self, Vec<Inserter<T>>)
Sourcepub async fn get(&mut self) -> Option<T>
pub async fn get(&mut self) -> Option<T>
Fetch the next ordered item produced by senders.
This may wait for at each sender to have sent at least one value before the Linearizer
starts producing.
If all senders have closed their channels and there are no more buffered values, this
returns None.