pub struct RuntimeManager { /* private fields */ }Implementations
Sourceimpl RuntimeManager
impl RuntimeManager
Sourcepub fn block_in_place<R, F: FnOnce() -> R>(&self, f: F) -> R
pub fn block_in_place<R, F: FnOnce() -> R>(&self, f: F) -> R
Runs the given function on this thread while allowing another thread to take over this thread’s task execution duties.
Simply directly calls f() if this thread is not an async executor thread.
Sourcepub fn block_in_place_on<F>(&self, future: F) -> F::Outputwhere
F: Future,
pub fn block_in_place_on<F>(&self, future: F) -> F::Outputwhere
F: Future,
Blocks this thread to evaluate the given future.
This is more expensive than block_on when called from an async runtime worker thread because other async tasks scheduled to run on this thread have to be moved to a new thread.
If more than POLARS_MAX_BLOCKING_THREAD_COUNT calls to this occur simultaneously a deadlock may occur.
Sourcepub fn block_on<F>(&self, future: F) -> F::Outputwhere
F: Future,
pub fn block_on<F>(&self, future: F) -> F::Outputwhere
F: Future,
Blocks this thread to evaluate the given future.
Panics if the current thread is an async runtime worker thread.
Sourcepub fn spawn<F>(&self, future: F) -> JoinHandle<F::Output>
pub fn spawn<F>(&self, future: F) -> JoinHandle<F::Output>
Spawns a future onto the Tokio runtime (see tokio::runtime::Runtime::spawn).
pub fn spawn_blocking<F, R>(&self, f: F) -> JoinHandle<R>